@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import wrappers_pb2 as wrappers  # type: ignore
+from google.protobuf import wrappers_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -28,7 +25,6 @@ __protobuf__ = proto.module(
 
 class EncryptionConfiguration(proto.Message):
     r"""
-
     Attributes:
         kms_key_name (google.protobuf.wrappers_pb2.StringValue):
             Optional. Describes the Cloud KMS encryption
@@ -38,7 +34,9 @@ class EncryptionConfiguration(proto.Message):
             this encryption key.
     """
 
-    kms_key_name = proto.Field(proto.MESSAGE, number=1, message=wrappers.StringValue,)
+    kms_key_name = proto.Field(
+        proto.MESSAGE, number=1, message=wrappers_pb2.StringValue,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
