@@ -673,14 +673,15 @@ class TestBigQuery(unittest.TestCase):
             mode=old_field.mode,
             description=None,
             fields=old_field.fields,
-            policy_tags=None,
+            policy_tags=PolicyTagList(),
         )
 
         table.schema = new_schema
         updated_table = Config.CLIENT.update_table(table, ["schema"])
 
         self.assertFalse(updated_table.schema[1].description)  # Empty string or None.
-        self.assertEqual(updated_table.schema[1].policy_tags.names, ())
+        # policyTags key expected to be missing from response.
+        self.assertIsNone(updated_table.schema[1].policy_tags)
 
     def test_update_table_clustering_configuration(self):
         dataset = self.temp_dataset(_make_dataset_id("update_table"))
@@ -1586,9 +1587,15 @@ class TestBigQuery(unittest.TestCase):
         query_job = Config.CLIENT.query(sql)
         query_job.result()
 
-        # Transaction ID set by the server should be accessible
-        assert query_job.transaction_info is not None
-        assert query_job.transaction_info.transaction_id != ""
+        child_jobs = Config.CLIENT.list_jobs(parent_job=query_job)
+        begin_transaction_job = next(iter(child_jobs))
+
+        # Transaction ID set by the server should be accessible on the child
+        # job responsible for `BEGIN TRANSACTION`. It is not expected to be
+        # present on the parent job itself.
+        # https://github.com/googleapis/python-bigquery/issues/975
+        assert begin_transaction_job.transaction_info is not None
+        assert begin_transaction_job.transaction_info.transaction_id != ""
 
     def test_dbapi_w_standard_sql_types(self):
         for sql, expected in helpers.STANDARD_SQL_EXAMPLES:
